==> openapi-typescript-plugin-1.1.2.tgz: package/CHANGELOG.md <==
# @openapi-qraft/openapi-typescript

## 1.1.2

### Patch Changes

- bb229fb: Resolved conflict between explicit exports and generated enum exports by aligning export strategy.
  - @openapi-qraft/plugin@1.14.2

## 1.1.1

### Patch Changes

- @openapi-qraft/plugin@1.14.1

## 1.1.0

### Minor Changes

- 0df334b: Added `--explicit-component-exports` option to export API components as separate type aliases alongside `components` interface by [@EcksDy](https://github.com/EcksDy)
- 787f568: Updated `openapi-typescript` to `^7.3.0`.

### Patch Changes

- Updated dependencies [77f0812]
- Updated dependencies [7430754]
- Updated dependencies [346a408]
- Updated dependencies [787f568]
  - @openapi-qraft/plugin@1.14.0

## 1.1.0-beta.5

### Minor Changes

- 0df334b: Added `--explicit-component-exports` option to export API components as separate type aliases alongside `components` interface by [@EcksDy](https://github.com/EcksDy)

### Patch Changes

- @openapi-qraft/plugin@1.14.0-beta.5

## 1.1.0-beta.4

### Patch Changes

- Updated dependencies [346a408]
  - @openapi-qraft/plugin@1.14.0-beta.4

## 1.1.0-beta.3

### Patch Changes

- Updated dependencies [c5c4426]
  - @openapi-qraft/plugin@1.14.0-beta.3

## 1.1.0-beta.2

### Patch Changes

- Updated dependencies [7430754]
  - @openapi-qraft/plugin@1.14.0-beta.2

## 1.1.0-beta.0

### Minor Changes

- 787f568: Updated `openapi-typescript` to `^7.3.0`.

### Patch Changes

- Updated dependencies [77f0812]
- Updated dependencies [787f568]
  - @openapi-qraft/plugin@1.14.0-beta.0

## 1.0.8

### Patch Changes

- Updated dependencies [63ba3ff]
  - @openapi-qraft/plugin@1.13.1

## 1.0.7

### Patch Changes

- Updated dependencies [6eec6d9]
  - @openapi-qraft/plugin@1.13.0

## 1.0.7-beta.2

### Patch Changes

- Updated dependencies [6eec6d9]
  - @openapi-qraft/plugin@1.13.0-beta.2

## 1.0.7-beta.1

### Patch Changes

- @openapi-qraft/plugin@1.13.0-beta.1

## 1.0.7-beta.0

### Patch Changes

- @openapi-qraft/plugin@1.13.0-beta.0

## 1.0.6

### Patch Changes

- @openapi-qraft/plugin@1.12.1

## 1.0.6-beta.0

### Patch Changes

- @openapi-qraft/plugin@1.12.1-beta.0

## 1.0.5

### Patch Changes

- Updated dependencies [d4bc3af]
  - @openapi-qraft/plugin@1.12.0

## 1.0.5-beta.2

### Patch Changes

- @openapi-qraft/plugin@1.12.0-beta.2

## 1.0.5-beta.1

### Patch Changes

- @openapi-qraft/plugin@1.12.0-beta.1

## 1.0.5-beta.0

### Patch Changes

- Updated dependencies [d4bc3af]
- Updated dependencies [3d2dd60]
  - @openapi-qraft/plugin@1.12.0-beta.0

## 1.0.4-beta.5

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.5

## 1.0.4-beta.4

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.4

## 1.0.4-beta.3

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.3

## 1.0.4-beta.2

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.2

## 1.0.4-beta.1

### Patch Changes

- Updated dependencies [3d2dd60]
  - @openapi-qraft/plugin@1.11.0-beta.1

## 1.0.4-beta.0

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.0

## 1.0.3

### Patch Changes

- 1ed521e: Default behavior now removes `.ts` extension from import paths. This behavior can be overridden for the `@openapi-qraft/tanstack-query-react-plugin` using the `--openapi-types-import-path <path>` option, which allows specifying the full import path, including the `.ts` extension.
  - @openapi-qraft/plugin@1.10.1

## 1.0.3-beta.2

### Patch Changes

- @openapi-qraft/plugin@1.10.1-beta.2

## 1.0.3-beta.1

### Patch Changes

- @openapi-qraft/plugin@1.10.1-beta.1

## 1.0.3-beta.0

### Patch Changes

- 1ed521e: Default behavior now removes `.ts` extension from import paths. This behavior can be overridden for the `@openapi-qraft/tanstack-query-react-plugin` using the `--openapi-types-import-path <path>` option, which allows specifying the full import path, including the `.ts` extension.
  - @openapi-qraft/plugin@1.10.1-beta.0

## 1.0.2

### Patch Changes

- Updated dependencies [b04f28d]
  - @openapi-qraft/plugin@1.10.0

## 1.0.1

### Patch Changes

- Updated dependencies [943a9d3]
- Updated dependencies [3a75364]
  - @openapi-qraft/plugin@1.9.0

## 1.0.0

### Major Changes

- c545cb2: chore: First release of the `@openapi-qraft/*` packages.

## 1.0.0-beta.1

### Major Changes

- 2034eba: First release of the `@openapi-qraft/*` packages.

==> openapi-typescript-plugin-1.2.0.tgz: package/CHANGELOG.md <==
# @openapi-qraft/openapi-typescript

## 1.2.0

### Minor Changes

- 2a53608: Updated TypeScript to version 5.5.4

### Patch Changes

- 9dc1918: Simplified `TParams` type for conditional expressions.
- cd8a856: Resolved conflict between explicit exports and generated enum exports by aligning export strategy.
- 34ff132: Added support for `void` and `undefined` arguments in mutation operations and `setQueryData`.
- Updated dependencies [16b380f]
- Updated dependencies [8c77eb2]
- Updated dependencies [2a53608]
- Updated dependencies [76634bf]
- Updated dependencies [c111be6]
- Updated dependencies [62ff8e0]
  - @openapi-qraft/plugin@2.0.0

## 1.2.0-next.19

### Patch Changes

- Updated dependencies [62ff8e0]
  - @openapi-qraft/plugin@2.0.0-next.19

## 1.2.0-next.18

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.18

## 1.2.0-next.17

### Patch Changes

- Updated dependencies [16b380f]
  - @openapi-qraft/plugin@2.0.0-next.17

## 1.2.0-next.16

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.16

## 1.2.0-next.15

### Patch Changes

- 4b1c13f: Fixed support for the `--explicit-import-extensions .ts` option when using the `openapi-typescript-plugin`.
  - @openapi-qraft/plugin@2.0.0-next.15

## 1.2.0-next.14

### Patch Changes

- 34ff132: Added support for `void` and `undefined` arguments in mutation operations and `setQueryData`.
  - @openapi-qraft/plugin@2.0.0-next.14

## 1.2.0-next.13

### Patch Changes

- Updated dependencies [c111be6]
  - @openapi-qraft/plugin@2.0.0-next.13

## 1.2.0-next.12

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.12

## 1.2.0-next.11

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.11

## 1.2.0-next.10

### Patch Changes

- Updated dependencies [8c77eb2]
  - @openapi-qraft/plugin@2.0.0-next.10

## 1.2.0-next.9

### Patch Changes

- 9dc1918: Simplified `TParams` type for conditional expressions.
  - @openapi-qraft/plugin@2.0.0-next.9

## 1.2.0-next.8

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.8

## 1.2.0-next.7

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.7

## 1.2.0-next.6

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.6

## 1.2.0-next.5

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.5

## 1.2.0-next.4

### Patch Changes

- cd8a856: Resolved conflict between explicit exports and generated enum exports by aligning export strategy.
  - @openapi-qraft/plugin@2.0.0-next.4

## 1.2.0-next.3

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.3

## 1.2.0-next.2

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.2

## 1.2.0-next.1

### Minor Changes

- 2a53608: Updated TypeScript to version 5.5.4

### Patch Changes

- Updated dependencies [2a53608]
- Updated dependencies [76634bf]
  - @openapi-qraft/plugin@2.0.0-next.1

## 1.1.1-next.0

### Patch Changes

- @openapi-qraft/plugin@2.0.0-next.0

## 1.1.0

### Minor Changes

- 0df334b: Added `--explicit-component-exports` option to export API components as separate type aliases alongside `components` interface by [@EcksDy](https://github.com/EcksDy)
- 787f568: Updated `openapi-typescript` to `^7.3.0`.

### Patch Changes

- Updated dependencies [77f0812]
- Updated dependencies [7430754]
- Updated dependencies [346a408]
- Updated dependencies [787f568]
  - @openapi-qraft/plugin@1.14.0

## 1.1.0-beta.5

### Minor Changes

- 0df334b: Added `--explicit-component-exports` option to export API components as separate type aliases alongside `components` interface by [@EcksDy](https://github.com/EcksDy)

### Patch Changes

- @openapi-qraft/plugin@1.14.0-beta.5

## 1.1.0-beta.4

### Patch Changes

- Updated dependencies [346a408]
  - @openapi-qraft/plugin@1.14.0-beta.4

## 1.1.0-beta.3

### Patch Changes

- Updated dependencies [c5c4426]
  - @openapi-qraft/plugin@1.14.0-beta.3

## 1.1.0-beta.2

### Patch Changes

- Updated dependencies [7430754]
  - @openapi-qraft/plugin@1.14.0-beta.2

## 1.1.0-beta.0

### Minor Changes

- 787f568: Updated `openapi-typescript` to `^7.3.0`.

### Patch Changes

- Updated dependencies [77f0812]
- Updated dependencies [787f568]
  - @openapi-qraft/plugin@1.14.0-beta.0

## 1.0.8

### Patch Changes

- Updated dependencies [63ba3ff]
  - @openapi-qraft/plugin@1.13.1

## 1.0.7

### Patch Changes

- Updated dependencies [6eec6d9]
  - @openapi-qraft/plugin@1.13.0

## 1.0.7-beta.2

### Patch Changes

- Updated dependencies [6eec6d9]
  - @openapi-qraft/plugin@1.13.0-beta.2

## 1.0.7-beta.1

### Patch Changes

- @openapi-qraft/plugin@1.13.0-beta.1

## 1.0.7-beta.0

### Patch Changes

- @openapi-qraft/plugin@1.13.0-beta.0

## 1.0.6

### Patch Changes

- @openapi-qraft/plugin@1.12.1

## 1.0.6-beta.0

### Patch Changes

- @openapi-qraft/plugin@1.12.1-beta.0

## 1.0.5

### Patch Changes

- Updated dependencies [d4bc3af]
  - @openapi-qraft/plugin@1.12.0

## 1.0.5-beta.2

### Patch Changes

- @openapi-qraft/plugin@1.12.0-beta.2

## 1.0.5-beta.1

### Patch Changes

- @openapi-qraft/plugin@1.12.0-beta.1

## 1.0.5-beta.0

### Patch Changes

- Updated dependencies [d4bc3af]
- Updated dependencies [3d2dd60]
  - @openapi-qraft/plugin@1.12.0-beta.0

## 1.0.4-beta.5

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.5

## 1.0.4-beta.4

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.4

## 1.0.4-beta.3

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.3

## 1.0.4-beta.2

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.2

## 1.0.4-beta.1

### Patch Changes

- Updated dependencies [3d2dd60]
  - @openapi-qraft/plugin@1.11.0-beta.1

## 1.0.4-beta.0

### Patch Changes

- @openapi-qraft/plugin@1.11.0-beta.0

## 1.0.3

### Patch Changes

- 1ed521e: Default behavior now removes `.ts` extension from import paths. This behavior can be overridden for the `@openapi-qraft/tanstack-query-react-plugin` using the `--openapi-types-import-path <path>` option, which allows specifying the full import path, including the `.ts` extension.
  - @openapi-qraft/plugin@1.10.1

## 1.0.3-beta.2

### Patch Changes

- @openapi-qraft/plugin@1.10.1-beta.2

## 1.0.3-beta.1

### Patch Changes

- @openapi-qraft/plugin@1.10.1-beta.1

## 1.0.3-beta.0

### Patch Changes

- 1ed521e: Default behavior now removes `.ts` extension from import paths. This behavior can be overridden for the `@openapi-qraft/tanstack-query-react-plugin` using the `--openapi-types-import-path <path>` option, which allows specifying the full import path, including the `.ts` extension.
  - @openapi-qraft/plugin@1.10.1-beta.0

## 1.0.2

### Patch Changes

- Updated dependencies [b04f28d]
  - @openapi-qraft/plugin@1.10.0

## 1.0.1

### Patch Changes

- Updated dependencies [943a9d3]
- Updated dependencies [3a75364]
  - @openapi-qraft/plugin@1.9.0

## 1.0.0

### Major Changes

- c545cb2: chore: First release of the `@openapi-qraft/*` packages.

## 1.0.0-beta.1

### Major Changes

- 2034eba: First release of the `@openapi-qraft/*` packages.
